@@ -1,8 +1,7 @@
 use std::fmt::Debug;
 use std::io::Cursor;
 
-use fluvio_protocol_core::{Decoder, Encoder};
-use fluvio_protocol_derive::{Decoder, Encoder};
+use fluvio_protocol::{Decoder, Encoder};
 
 #[derive(Encoder, Decoder, Default, Debug)]
 pub struct GenericRecord<R>
